2024-10-24 Version: 2.6.0
- Support API OperateAvatarProject.
- Support API QuerySessionInfo.
- Support API SaveAvatarProject.
- Update API ListAnchor: add param resSpecType.
- Update API ListVoiceModels: add param resSpecType.
- Update API QueryAvatarProject: update response param.
- Update API StartAvatarSession: update param body.
- Update API SubmitProjectTask: update param body.


2024-09-29 Version: 2.5.0
- Support API InteractText.
- Support API ListAvatarProject.
- Update API SubmitProjectTask: update param body.


2024-09-09 Version: 2.4.0
- Support API CreateRealisticPortrait.
- Support API QueryTextStream.
- Support API SelectImageTask.
- Support API TransferPortraitStyle.
- Update API StartAvatarSession: update response param.
- Update API SubmitProjectTask: update param body.


2024-08-20 Version: 2.3.0
- Support API BatchGetProjectTask.


2024-08-07 Version: 2.2.0
- Support API CountText.
- Update API ListTexts: add param keyword.
- Update API SubmitProjectTask: update param body.


2024-07-22 Version: 2.1.4
- Generated python 2024-03-13 for IntelligentCreation.

2024-07-22 Version: 2.1.3
- Generated python 2024-03-13 for IntelligentCreation.

2024-07-22 Version: 2.1.2
- Generated python 2024-03-13 for IntelligentCreation.

2024-07-19 Version: 2.1.1
- Generated python 2024-03-13 for IntelligentCreation.

2024-07-19 Version: 2.1.0
- Support API AddTextFeedback.
- Support API CheckSession.
- Support API GetProjectTask.
- Support API GetTextTemplate.
- Support API ListAnchor.
- Support API ListVoiceModels.
- Support API QueryAvatarProject.
- Support API QueryAvatarResource.
- Support API SelectResource.
- Support API SendTextMsg.
- Support API StartAvatarSession.
- Support API StopAvatarSession.
- Support API StopProjectTask.
- Support API SubmitProjectTask.


2024-06-17 Version: 2.0.2
- Generated python 2024-03-13 for IntelligentCreation.

2024-06-13 Version: 2.0.1
- Generated python 2024-03-13 for IntelligentCreation.

2024-05-29 Version: 2.0.0
- Support API ListTexts.
- Update API ListTextThemes: add param industry.


2024-05-20 Version: 1.0.0
- Generated python 2024-03-13 for IntelligentCreation.

